<?php

namespace Litecms\Category\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Category\Interfaces\ProductCategoryRepositoryInterface;

class ProductCategoryPublicController extends BaseController
{
    // use ProductCategoryWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\ProductCategory\Interfaces\ProductCategoryRepositoryInterface $product_category
     *
     * @return type
     */
    public function __construct(ProductCategoryRepositoryInterface $product_category)
    {
        $this->repository = $product_category;
        parent::__construct();
    }

    /**
     * Show product_category's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $product_categories = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$category::$product_category.names'))
            ->view('$category::public.product_category.index')
            ->data(compact('$product_categories'))
            ->output();
    }

    /**
     * Show product_category's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $product_categories = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$category::$product_category.names'))
            ->view('$category::public.product_category.index')
            ->data(compact('$product_categories'))
            ->output();
    }

    /**
     * Show product_category.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $product_category = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$product_category->name . trans('$category::$product_category.name'))
            ->view('$category::public.product_category.show')
            ->data(compact('$product_category'))
            ->output();
    }

}
