<?php

namespace Litecms\Category\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Category\Models\ProductCategory;

class ProductCategoryPolicy
{

    /**
     * Determine if the given user can view the product_category.
     *
     * @param UserPolicy $user
     * @param ProductCategory $product_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, ProductCategory $product_category)
    {
        if ($user->canDo('category.product_category.view') && $user->isAdmin()) {
            return true;
        }

        return $product_category->user_id == user_id() && $product_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a product_category.
     *
     * @param UserPolicy $user
     * @param ProductCategory $product_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('category.product_category.create');
    }

    /**
     * Determine if the given user can update the given product_category.
     *
     * @param UserPolicy $user
     * @param ProductCategory $product_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, ProductCategory $product_category)
    {
        if ($user->canDo('category.product_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $product_category->user_id == user_id() && $product_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given product_category.
     *
     * @param UserPolicy $user
     * @param ProductCategory $product_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ProductCategory $product_category)
    {
        return $product_category->user_id == user_id() && $product_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given product_category.
     *
     * @param UserPolicy $user
     * @param ProductCategory $product_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ProductCategory $product_category)
    {
        if ($user->canDo('category.product_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product_category.
     *
     * @param UserPolicy $user
     * @param ProductCategory $product_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ProductCategory $product_category)
    {
        if ($user->canDo('category.product_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
